@@ -8,7 +8,7 @@ from rest_framework.views import APIView
 
 from config.config import Config
 from xj_payment.common import get_domain
-from xj_payment.services.payment_service import PaymentService
+# from xj_payment.services.payment_service import PaymentService
 from xj_payment.utils.utils import my_ali_pay, is_app_pay
 
 
